@@ -1,5 +1,5 @@
 /*-------------------------------------------------------------------------------------*/
-/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search - version 3.5.1        */
+/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search - version 3.6.2        */
 /*                                                                                     */
 /*  Copyright (C) 2001-2012  Mark Abramson        - the Boeing Company, Seattle        */
 /*                           Charles Audet        - Ecole Polytechnique, Montreal      */
@@ -46,7 +46,6 @@
 #include "utils.hpp"
 
 namespace NOMAD {
-		using namespace std;
 
   /// Custom display class.
   /**
@@ -133,7 +132,7 @@ namespace NOMAD {
                   (can be a \c std::ofstream)
 		  -- \b IN -- \b optional (default = \c std::cout).
      */
-    Display ( std::ostream & out )	// = std::cout )  //R does not like std::cout,   so we comment this default value.  zhenghua
+    Display ( std::ostream & out = NOMAD::rout ) // R does not like std::cout,  so we comment this default value. zhenghua
       : _out          ( out                   ) , // can be a std::ofstream
 	_newline      ( true                  ) ,
 	_open_brace   ( "{"                   ) ,
@@ -294,7 +293,7 @@ namespace NOMAD {
     /**
        \return An integer for the current precision.
     */
-	int precision ( void ) const { return static_cast<int>(_out.precision()); }
+    int precision ( void ) const { return static_cast<int>(_out.precision()); }
 
     /// Set the format flags (1/2).
     /**
